require 'test_helper'

class CreateInvitationTest < ActionDispatch::IntegrationTest

  def setup
    ENV['INVITATION_ONLY'] = 'true'
  end

  def teardown
    ENV['INVITATION_KEY'] = 'false'
  end

  test 'show new invitation view (valid)' do
    get '/cally/invitations'
    assert_template 'invitations/new'
  end

  test 'show new invitation view when not invitation subscription (invalid)' do
    ENV['INVITATION_ONLY'] = 'false'
    get '/cally/invitations'
    follow_redirect!
    assert_template 'users/new'
    assert_match 'This is an open subscription, no invitation needed.', response.body
  end

  test 'create invitation (valid)' do
    get '/cally/invitations'
    assert_template 'invitations/new'
    assert_difference '::Cally::Invitation.count' do
      post '/cally/invitations', params: { invitation: { email: 'aa@example.com' } }
      follow_redirect!
    end
    assert_match "Created invitation request for 'aa@example.com'.", response.body
  end

  test 'create invitation with already used email (invalid)' do
    get '/cally/invitations'
    assert_template 'invitations/new'
    assert_no_difference '::Cally::Invitation.count' do
      post '/cally/invitations', params: { invitation: { email: 'sid@example.com' } }
      #follow_redirect!
    end
    assert_match 'Error create invitation request.', response.body
  end

  test 'create invitation when it is not an invitation subscription (invalid)' do
    ENV['INVITATION_ONLY'] = 'false'
    assert_no_difference '::Cally::Invitation.count' do
      post '/cally/invitations', params: { invitation: { email: 'aa@example.com' } }
      follow_redirect!
    end
    assert_match 'This is an open subscription, no invitation needed.', response.body
  end
end
