require 'test_helper'

class CreateUserTest < ActionDispatch::IntegrationTest

  def teardown
    ENV['INVITATION_ONLY'] = 'false'
  end

  test 'create first user (is admin)(valid)' do
    ::Cally::User.destroy_all
    get '/cally/users/new'
    assert_template 'users/new'
    assert_difference '::Cally::User.count' do
      post '/cally/users', params: { user: { username: 'Jane', 
                                                email: 'jane@example.com', 
                                                password: 'jane12345678901234567890',
                                                security_question: 'firstname',
                                                security_answer: 'jane' } }
      follow_redirect!
    end
    assert_match "User 'Jane' successfully created.", response.body
    assert ::Cally::User.last.reload.admin
  end

  test 'create second user (no admin)(valid)' do
    get '/cally/users/new'
    assert_template 'users/new'
    assert_difference '::Cally::User.count' do
      post '/cally/users', params: { user: { username: 'Jane', 
                                                email: 'jane@example.com', 
                                                password: 'jane12345678901234567890', 
                                                security_question: 'firstname', 
                                                security_answer: 'jane' } }
      follow_redirect!
    end
    assert_match "User 'Jane' successfully created.", response.body
    assert_not ::Cally::User.last.reload.admin
  end
 
  test 'create user when env var invitation_only is set to true (invalid)' do
    ENV['INVITATION_ONLY'] = 'true'
    get '/cally/users/new'
    follow_redirect!
    assert_match 'This is invitation only, enter your email for asking for invitation.', response.body
  end

  test 'create user from invitation (valid).' do
    ENV['INVITATION_ONLY'] = 'true'
    @invite1 = cally_invitations(:invite1)
    get "/cally/invitation/#{@invite1.invitation_key}"
    assert_template 'users/new'
    assert_difference '::Cally::User.count' do
      post '/cally/users', params: { user: { username: 'Sid', 
                                                email: "#{@invite1.email}", 
                                                password: 'sid12345678901234567890', 
                                                security_question: 'firstname', 
                                                security_answer: 'sid',
                                                invitation_key: "#{@invite1.invitation_key}"} }
      follow_redirect!
    end
    assert_match "User 'Sid' successfully created.", response.body
  end

  test 'create user from non-existent invitation (invalid).' do
    ENV['INVITATION_ONLY'] = 'true'
    get '/cally/invitation/9999'
    follow_redirect!
    assert_template 'invitations/new'
    assert_match 'This is invitation only, enter your email for asking for invitation.', response.body
    assert_no_difference '::Cally::User.count' do
      post '/cally/users', params: { user: {
        username: 'invalid user',
        email: 'invalid_user@example.com',
        password: 'invalid_user12345678901234567890',
        security_question: 'firstname',
        security_answer: 'invlaid user',
        invitation_key: 'invalid_key'
      } }
      follow_redirect!
    end
    assert_match 'This is invitation only', response.body
  end
end
