require 'test_helper'

class DeleteInvitationTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
    @joe = cally_users(:joe)
    @invite1 = cally_invitations(:invite1)

    ENV['INVITATION_ONLY'] = 'true'
  end

  def teardown
    ENV['INVITATION_ONLY'] = 'false'
  end

  test 'delete invitation as admin (valid).' do
    login_as(@john, 'john12345678901234567890')
    get '/cally/invitations/all'
    assert_template 'invitations/index'
    assert_difference '::Cally::Invitation.count', -1 do
      delete "/cally/invitations/#{@invite1.id}"
      follow_redirect!
    end
    assert_match 'Invitation successfully deleted.', response.body
  end

  test 'delete invitation as non-admin (invalid).' do
    login_as(@joe, 'joe12345678901234567890')
    assert_no_difference '::Cally::Invitation.count' do
      delete "/cally/invitations/#{@invite1.id}"
      follow_redirect!
    end
    assert_match 'You need to be admin for this action.', response.body
  end

  test 'delete invitation when not logged in (invlaid).' do
    assert_no_difference '::Cally::Invitation.count' do
      delete "/cally/invitations/#{@invite1.id}"
      follow_redirect!
    end
    assert_match 'You need to be admin for this action.', response.body
  end
end
