require 'test_helper'

class DeleteUserTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
    @joe = cally_users(:joe)
  end

  test 'Remove your own account (valid)' do
    login_as(@joe, 'joe12345678901234567890')
    assert_difference '::Cally::User.count', -1 do
      delete "/cally/users/#{@joe.id}"
      follow_redirect! 
    end
    assert_match 'User successfully deleted.', response.body
  end

  test 'Remove other user as admin (valid)' do
    login_as(@john, 'john12345678901234567890')
    assert_difference '::Cally::User.count', -1 do
      delete "/cally/users/#{@joe.id}"
      follow_redirect!
    end
    assert_match 'User successfully deleted.', response.body
  end

  test 'Remove other user as non-admin (invalid)' do
    login_as(@joe, 'joe12345678901234567890')
    assert_no_difference '::Cally::User.count' do
      delete "/cally/users/#{@john.id}"
      follow_redirect!
    end
    assert_match 'You can only perform this action as your own or an admin account.', response.body
  end

  test 'Remove user when not logged in (invalid)' do
    assert_no_difference '::Cally::User.count' do
      delete "/cally/users/#{@joe.id}"
      follow_redirect!
    end
    assert_match 'You can only perform this action as your own or an admin account.', response.body
  end
end
