require 'test_helper'

class EditUserTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
    @joe = cally_users(:joe)
  end

  test 'change username as owner (valid)' do
    login_as(@john, 'john12345678901234567890')
    get "/cally/users/#{@john.id}/edit"
    assert_template 'users/edit'
    put "/cally/users/#{@john.id}", params: { user: { username: 'John2' } }
    follow_redirect!
    assert_template 'users/show'
    assert_match 'Your profile is updated successfully.', response.body
  end

  test 'change email as owner (valid)' do
    login_as(@john, 'john12345678901234567890')
    get "/cally/users/#{@john.id}/edit"
    assert_template 'users/edit'
    put "/cally/users/#{@john.id}", params: { user: { email: 'John2@example.com' } }
    follow_redirect!
    assert_template 'users/show'
    assert_match 'Your profile is updated successfully.', response.body
  end

  test 'change password as owner (valid)' do
    login_as(@john, 'john12345678901234567890')
    get "/cally/users/#{@john.id}/edit"
    assert_template 'users/edit'
    put "/cally/users/#{@john.id}", params: { user: { password: 'john1234567890123456789011' } }
    follow_redirect!
    assert_template 'users/show'
    assert_match 'Your profile is updated successfully.', response.body
  end

  test 'change profile when not logged in (invalid)' do
    get "/cally/users/#{@john.id}/edit"
    follow_redirect!
    assert_template 'users/login'
    put "/cally/users/#{@john.id}", params: { user: { username: 'John2' } }
    follow_redirect!
    assert_match 'You can only view your own profile.', response.body
  end

  test 'change other user profile (invalid)' do
    login_as(@john, 'john12345678901234567890')
    get "/cally/users/#{@joe.id}/edit"
    follow_redirect!
    assert_template 'users/login'
    put "/cally/users/#{@joe.id}", params: { user: { password: 'john1234567890123456789011' } }
    follow_redirect!
    assert_template 'users/login'
    assert_match 'You can only view your own profile.', response.body
  end
end
