require 'test_helper'

class LoginLogoutTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
  end

  test 'login with valid email and password (valid)' do
    get '/cally/login'
    assert_template 'users/login'
    post '/cally/login', params: { session: { email: @john.email, password: 'john12345678901234567890' } }
    follow_redirect!
    assert_template 'users/show'
    assert_match "Welcome #{@john.username}", response.body
  end

  test 'login with invalid email (invalid)' do
    get '/cally/login'
    #follow_redirect!
    assert_template 'users/login'
    post '/cally/login', params: { session: { email: 'test@test.com', password: 'john12345678901234567890' } }
    follow_redirect!
    assert_template 'users/login'
    assert_match 'Error logging in', response.body
  end

  test 'login with invalid password (invalid)' do
    get '/cally/login'
    #follow_redirect!
    assert_template 'users/login'
    post '/cally/login', params: { session: { email: @john.email, password: 'john' } }
    follow_redirect!
    assert_template 'users/login'
    assert_match 'Error logging in', response.body
  end

  test 'logout (valid)' do
    get '/cally/login'
    #follow_redirect!
    assert_template 'users/login'
    post '/cally/login', params: { session: { email: @john.email, password: 'john12345678901234567890' } }
    follow_redirect!
    assert_template 'users/show'
    assert_match "Welcome #{@john.username}", response.body
    delete '/cally/logout'
    follow_redirect!
    assert_template 'users/login'
    assert_match 'Successfully logged out', response.body
  end
end
