require 'test_helper'

class SendInvitationTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
    @joe = cally_users(:joe)
    @invite1 = cally_invitations(:invite1)
    ENV['INVITATION_ONLY'] = 'true'
  end

  def teardown
    ENV['INVITATION_ONLY'] = 'false'
  end

  test 'send invitation as admin (valid).' do
    login_as(@john, 'john12345678901234567890')
    get '/cally/invitations/all'
    assert_template 'invitations/index'
    get "/cally/send_invitation/#{@invite1.id}"
    follow_redirect!
    assert_match "Sent invitation to '#{@invite1.email}'", response.body
  end

  test 'send invitation as non-admin (invalid).' do
    login_as(@joe, 'joe12345678901234567890')
    get '/cally/invitations/all'
    follow_redirect!
    assert_template 'users/show'
    assert_match 'You need to be admin for this action.', response.body
    get "/cally/send_invitation/#{@invite1.id}"
    follow_redirect!
    assert_match 'You need to be admin for this action.', response.body
  end

  test 'send invitation when not logged in (invalid).' do
    get '/cally/invitations/all'
    follow_redirect!
    assert_template 'users/login'
    assert_match 'You need to be admin for this action.', response.body
    get "/cally/send_invitation/#{@invite1.id}"
    follow_redirect!
    assert_match 'You need to be admin for this action.', response.body
  end
end
