require 'test_helper'

class ToggleAdminRightsTest < ActionDispatch::IntegrationTest

  def setup
    @john = cally_users(:john)
    @joe = cally_users(:joe)
  end
  
  test 'give user admin rights as admin (valid)' do
    login_as(@john, 'john12345678901234567890')
    assert_not @joe.admin
    post "/cally/toggle_admin/#{@joe.id}"
    follow_redirect!
    assert @joe.reload.admin
    assert_match 'Admin status updated successfully.', response.body
  end

  test 'revoke user admin rights as admin (valid)' do
    login_as(@john, 'john12345678901234567890')
    post "/cally/toggle_admin/#{@joe.id}"
    follow_redirect!
    assert @joe.reload.admin
    post "/cally/toggle_admin/#{@joe.id}"
    follow_redirect!
    assert_not @joe.reload.admin
    assert_match 'Admin status updated successfully.', response.body
  end

  test 'toggle admin rights for first user (invalid)' do
    login_as(@john, 'john12345678901234567890')
    post "/cally/toggle_admin/#{@john.id}"
    follow_redirect!
    assert @john.reload.admin
    assert_match 'Error updating admin status.'  , response.body
  end

  test 'toggle admin rights as non-admin (invalid)' do
    login_as(@joe, 'joe12345678901234567890')
    post "/cally/toggle_admin/#{@joe.id}"
    follow_redirect!
    assert_not @joe.reload.admin
    assert_match 'You need to be admin for this action.' , response.body
  end

  test 'toggle admin rights when not logged in (invalid)' do
    post "/cally/toggle_admin/#{@joe.id}"
    follow_redirect!
    assert_not @joe.reload.admin
    assert_match 'You need to be admin for this action.' , response.body
  end
end
