require 'test_helper'

module Cally
  class UserTest < ActiveSupport::TestCase
  
    def setup
      @user = User.new(username: 'aaa', 
                       email: 'aaa@example.com', 
                       password: 'aaa12345678901234567890', 
                       security_question: 'firstname', 
                       security_answer: 'aaa')
    end
  
    test 'user created in setup is valid?' do
      assert @user.valid?
    end

    test 'username must be minimum 3 characters (invalid)' do
      @user.username = 'aa'
      assert_not @user.valid?
    end

    test 'username cannot contain more than 25 characters (invalid)' do
      @user.username = 'qbcdefghijklmnopqrstuvwxyz'
      assert_not @user.valid?
    end

    test 'username should be unique (invalid)' do
      @user.save
      user2 = User.new(username: 'aaa', 
                       email: 'bbb@example.com', 
                       password: 'bbb12345678901234567890', 
                       security_question: 'firstname', 
                       security_answer: 'aaa')
      assert_not user2.valid?
    end

    test 'username should not be empty (invalid)' do
      @user.username = ''
      assert_not @user.valid?
    end

    test 'user must have valid e-mail address (invalid)' do
      @user.email = 'aaa'
      assert_not @user.valid?
    end

    test 'user e-mail cannot be empty (invalid)' do
      @user.email = ''
      assert_not @user.valid?
    end

    test 'user must have security question (invalid)' do
      @user.security_question = ''
      assert_not @user.valid?
    end

    test 'user must have security answer (invalid)' do
      @user.security_answer = ''
      assert_not @user.valid?
    end

    test 'user e-mail must be unique (invalid)' do
      @user.save
      user2 = User.new(username: 'bbb', 
                       email: 'aaa@example.com', 
                       password: 'bbb12345678901234567890', 
                       security_question: 'firstname', 
                       security_answer: 'bbb')
      assert_not user2.valid?
    end

    test 'user password must be at least 15 characters (invalid)' do
      user2 = User.new(username: 'bbb', 
                       email: 'bbb@example.com', 
                       password: 'bb', 
                       security_question: 'firstname', 
                       security_answer: 'bbb')
      assert_not user2.valid?
    end
  end
end
